# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_connect_harness_compartment_details import ChangeConnectHarnessCompartmentDetails
from .change_stream_compartment_details import ChangeStreamCompartmentDetails
from .change_stream_pool_compartment_details import ChangeStreamPoolCompartmentDetails
from .connect_harness import ConnectHarness
from .connect_harness_summary import ConnectHarnessSummary
from .create_connect_harness_details import CreateConnectHarnessDetails
from .create_cursor_details import CreateCursorDetails
from .create_group_cursor_details import CreateGroupCursorDetails
from .create_stream_details import CreateStreamDetails
from .create_stream_pool_details import CreateStreamPoolDetails
from .cursor import Cursor
from .custom_encryption_key import CustomEncryptionKey
from .custom_encryption_key_details import CustomEncryptionKeyDetails
from .group import Group
from .kafka_settings import KafkaSettings
from .message import Message
from .partition_reservation import PartitionReservation
from .private_endpoint_details import PrivateEndpointDetails
from .private_endpoint_settings import PrivateEndpointSettings
from .put_messages_details import PutMessagesDetails
from .put_messages_details_entry import PutMessagesDetailsEntry
from .put_messages_result import PutMessagesResult
from .put_messages_result_entry import PutMessagesResultEntry
from .stream import Stream
from .stream_pool import StreamPool
from .stream_pool_summary import StreamPoolSummary
from .stream_summary import StreamSummary
from .update_connect_harness_details import UpdateConnectHarnessDetails
from .update_group_details import UpdateGroupDetails
from .update_stream_details import UpdateStreamDetails
from .update_stream_pool_details import UpdateStreamPoolDetails

# Maps type names to classes for streaming services.
streaming_type_mapping = {
    "ChangeConnectHarnessCompartmentDetails": ChangeConnectHarnessCompartmentDetails,
    "ChangeStreamCompartmentDetails": ChangeStreamCompartmentDetails,
    "ChangeStreamPoolCompartmentDetails": ChangeStreamPoolCompartmentDetails,
    "ConnectHarness": ConnectHarness,
    "ConnectHarnessSummary": ConnectHarnessSummary,
    "CreateConnectHarnessDetails": CreateConnectHarnessDetails,
    "CreateCursorDetails": CreateCursorDetails,
    "CreateGroupCursorDetails": CreateGroupCursorDetails,
    "CreateStreamDetails": CreateStreamDetails,
    "CreateStreamPoolDetails": CreateStreamPoolDetails,
    "Cursor": Cursor,
    "CustomEncryptionKey": CustomEncryptionKey,
    "CustomEncryptionKeyDetails": CustomEncryptionKeyDetails,
    "Group": Group,
    "KafkaSettings": KafkaSettings,
    "Message": Message,
    "PartitionReservation": PartitionReservation,
    "PrivateEndpointDetails": PrivateEndpointDetails,
    "PrivateEndpointSettings": PrivateEndpointSettings,
    "PutMessagesDetails": PutMessagesDetails,
    "PutMessagesDetailsEntry": PutMessagesDetailsEntry,
    "PutMessagesResult": PutMessagesResult,
    "PutMessagesResultEntry": PutMessagesResultEntry,
    "Stream": Stream,
    "StreamPool": StreamPool,
    "StreamPoolSummary": StreamPoolSummary,
    "StreamSummary": StreamSummary,
    "UpdateConnectHarnessDetails": UpdateConnectHarnessDetails,
    "UpdateGroupDetails": UpdateGroupDetails,
    "UpdateStreamDetails": UpdateStreamDetails,
    "UpdateStreamPoolDetails": UpdateStreamPoolDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SteeringPolicyPriorityAnswerData(object):
    """
    SteeringPolicyPriorityAnswerData model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SteeringPolicyPriorityAnswerData object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param answer_condition:
            The value to assign to the answer_condition property of this SteeringPolicyPriorityAnswerData.
        :type answer_condition: str

        :param value:
            The value to assign to the value property of this SteeringPolicyPriorityAnswerData.
        :type value: int

        """
        self.swagger_types = {
            'answer_condition': 'str',
            'value': 'int'
        }

        self.attribute_map = {
            'answer_condition': 'answerCondition',
            'value': 'value'
        }

        self._answer_condition = None
        self._value = None

    @property
    def answer_condition(self):
        """
        Gets the answer_condition of this SteeringPolicyPriorityAnswerData.
        An expression that is used to select a set of answers that match a condition. For example, answers with matching pool properties.


        :return: The answer_condition of this SteeringPolicyPriorityAnswerData.
        :rtype: str
        """
        return self._answer_condition

    @answer_condition.setter
    def answer_condition(self, answer_condition):
        """
        Sets the answer_condition of this SteeringPolicyPriorityAnswerData.
        An expression that is used to select a set of answers that match a condition. For example, answers with matching pool properties.


        :param answer_condition: The answer_condition of this SteeringPolicyPriorityAnswerData.
        :type: str
        """
        self._answer_condition = answer_condition

    @property
    def value(self):
        """
        **[Required]** Gets the value of this SteeringPolicyPriorityAnswerData.
        The rank assigned to the set of answers that match the expression in `answerCondition`.
        Answers with the lowest values move to the beginning of the list without changing the
        relative order of those with the same value. Answers can be given a value between `0` and `255`.


        :return: The value of this SteeringPolicyPriorityAnswerData.
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SteeringPolicyPriorityAnswerData.
        The rank assigned to the set of answers that match the expression in `answerCondition`.
        Answers with the lowest values move to the beginning of the list without changing the
        relative order of those with the same value. Answers can be given a value between `0` and `255`.


        :param value: The value of this SteeringPolicyPriorityAnswerData.
        :type: int
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CorsPolicy(object):
    """
    Enable CORS (Cross-Origin-Resource-Sharing) request handling.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CorsPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param allowed_origins:
            The value to assign to the allowed_origins property of this CorsPolicy.
        :type allowed_origins: list[str]

        :param allowed_methods:
            The value to assign to the allowed_methods property of this CorsPolicy.
        :type allowed_methods: list[str]

        :param allowed_headers:
            The value to assign to the allowed_headers property of this CorsPolicy.
        :type allowed_headers: list[str]

        :param exposed_headers:
            The value to assign to the exposed_headers property of this CorsPolicy.
        :type exposed_headers: list[str]

        :param is_allow_credentials_enabled:
            The value to assign to the is_allow_credentials_enabled property of this CorsPolicy.
        :type is_allow_credentials_enabled: bool

        :param max_age_in_seconds:
            The value to assign to the max_age_in_seconds property of this CorsPolicy.
        :type max_age_in_seconds: int

        """
        self.swagger_types = {
            'allowed_origins': 'list[str]',
            'allowed_methods': 'list[str]',
            'allowed_headers': 'list[str]',
            'exposed_headers': 'list[str]',
            'is_allow_credentials_enabled': 'bool',
            'max_age_in_seconds': 'int'
        }

        self.attribute_map = {
            'allowed_origins': 'allowedOrigins',
            'allowed_methods': 'allowedMethods',
            'allowed_headers': 'allowedHeaders',
            'exposed_headers': 'exposedHeaders',
            'is_allow_credentials_enabled': 'isAllowCredentialsEnabled',
            'max_age_in_seconds': 'maxAgeInSeconds'
        }

        self._allowed_origins = None
        self._allowed_methods = None
        self._allowed_headers = None
        self._exposed_headers = None
        self._is_allow_credentials_enabled = None
        self._max_age_in_seconds = None

    @property
    def allowed_origins(self):
        """
        **[Required]** Gets the allowed_origins of this CorsPolicy.
        The list of allowed origins that the CORS handler will use to respond to CORS requests. The gateway will
        send the Access-Control-Allow-Origin header with the best origin match for the circumstances. '*' will match
        any origins, and 'null' will match queries from 'file:' origins. All other origins must be qualified with the
        scheme, full hostname, and port if necessary.


        :return: The allowed_origins of this CorsPolicy.
        :rtype: list[str]
        """
        return self._allowed_origins

    @allowed_origins.setter
    def allowed_origins(self, allowed_origins):
        """
        Sets the allowed_origins of this CorsPolicy.
        The list of allowed origins that the CORS handler will use to respond to CORS requests. The gateway will
        send the Access-Control-Allow-Origin header with the best origin match for the circumstances. '*' will match
        any origins, and 'null' will match queries from 'file:' origins. All other origins must be qualified with the
        scheme, full hostname, and port if necessary.


        :param allowed_origins: The allowed_origins of this CorsPolicy.
        :type: list[str]
        """
        self._allowed_origins = allowed_origins

    @property
    def allowed_methods(self):
        """
        Gets the allowed_methods of this CorsPolicy.
        The list of allowed HTTP methods that will be returned for the preflight OPTIONS request in the
        Access-Control-Allow-Methods header. '*' will allow all methods.


        :return: The allowed_methods of this CorsPolicy.
        :rtype: list[str]
        """
        return self._allowed_methods

    @allowed_methods.setter
    def allowed_methods(self, allowed_methods):
        """
        Sets the allowed_methods of this CorsPolicy.
        The list of allowed HTTP methods that will be returned for the preflight OPTIONS request in the
        Access-Control-Allow-Methods header. '*' will allow all methods.


        :param allowed_methods: The allowed_methods of this CorsPolicy.
        :type: list[str]
        """
        self._allowed_methods = allowed_methods

    @property
    def allowed_headers(self):
        """
        Gets the allowed_headers of this CorsPolicy.
        The list of headers that will be allowed from the client via the Access-Control-Allow-Headers header.
        '*' will allow all headers.


        :return: The allowed_headers of this CorsPolicy.
        :rtype: list[str]
        """
        return self._allowed_headers

    @allowed_headers.setter
    def allowed_headers(self, allowed_headers):
        """
        Sets the allowed_headers of this CorsPolicy.
        The list of headers that will be allowed from the client via the Access-Control-Allow-Headers header.
        '*' will allow all headers.


        :param allowed_headers: The allowed_headers of this CorsPolicy.
        :type: list[str]
        """
        self._allowed_headers = allowed_headers

    @property
    def exposed_headers(self):
        """
        Gets the exposed_headers of this CorsPolicy.
        The list of headers that the client will be allowed to see from the response as indicated by the
        Access-Control-Expose-Headers header. '*' will expose all headers.


        :return: The exposed_headers of this CorsPolicy.
        :rtype: list[str]
        """
        return self._exposed_headers

    @exposed_headers.setter
    def exposed_headers(self, exposed_headers):
        """
        Sets the exposed_headers of this CorsPolicy.
        The list of headers that the client will be allowed to see from the response as indicated by the
        Access-Control-Expose-Headers header. '*' will expose all headers.


        :param exposed_headers: The exposed_headers of this CorsPolicy.
        :type: list[str]
        """
        self._exposed_headers = exposed_headers

    @property
    def is_allow_credentials_enabled(self):
        """
        Gets the is_allow_credentials_enabled of this CorsPolicy.
        Whether to send the Access-Control-Allow-Credentials header to allow CORS requests with cookies.


        :return: The is_allow_credentials_enabled of this CorsPolicy.
        :rtype: bool
        """
        return self._is_allow_credentials_enabled

    @is_allow_credentials_enabled.setter
    def is_allow_credentials_enabled(self, is_allow_credentials_enabled):
        """
        Sets the is_allow_credentials_enabled of this CorsPolicy.
        Whether to send the Access-Control-Allow-Credentials header to allow CORS requests with cookies.


        :param is_allow_credentials_enabled: The is_allow_credentials_enabled of this CorsPolicy.
        :type: bool
        """
        self._is_allow_credentials_enabled = is_allow_credentials_enabled

    @property
    def max_age_in_seconds(self):
        """
        Gets the max_age_in_seconds of this CorsPolicy.
        The time in seconds for the client to cache preflight responses. This is sent as the Access-Control-Max-Age
        if greater than 0.


        :return: The max_age_in_seconds of this CorsPolicy.
        :rtype: int
        """
        return self._max_age_in_seconds

    @max_age_in_seconds.setter
    def max_age_in_seconds(self, max_age_in_seconds):
        """
        Sets the max_age_in_seconds of this CorsPolicy.
        The time in seconds for the client to cache preflight responses. This is sent as the Access-Control-Max-Age
        if greater than 0.


        :param max_age_in_seconds: The max_age_in_seconds of this CorsPolicy.
        :type: int
        """
        self._max_age_in_seconds = max_age_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from . import analytics, announcements_service, apigateway, application_migration, audit, autoscaling, bds, blockchain, budget, cims, cloud_guard, container_engine, core, data_catalog, data_flow, data_integration, data_safe, data_science, database, dns, dts, email, events, file_storage, functions, healthchecks, identity, integration, key_management, limits, load_balancer, log_analytics, logging, loggingingestion, loggingsearch, management_agent, management_dashboard, marketplace, monitoring, mysql, nosql, object_storage, oce, ocvp, oda, ons, os_management, resource_manager, resource_search, sch, secrets, streaming, usage_api, vault, waas, work_requests
from . import auth, config, constants, decorators, exceptions, regions, pagination, retry, fips
from .base_client import BaseClient
from .request import Request
from .response import Response
from .signer import Signer
from .version import __version__  # noqa
from .waiter import wait_until

fips.enable_fips_mode()

__all__ = [
    "BaseClient", "Error", "Request", "Response", "Signer", "config", "constants", "decorators", "exceptions", "regions", "wait_until", "pagination", "auth", "retry", "fips",
    "analytics", "announcements_service", "apigateway", "application_migration", "audit", "autoscaling", "bds", "blockchain", "budget", "cims", "cloud_guard", "container_engine", "core", "data_catalog", "data_flow", "data_integration", "data_safe", "data_science", "database", "dns", "dts", "email", "events", "file_storage", "functions", "healthchecks", "identity", "integration", "key_management", "limits", "load_balancer", "log_analytics", "logging", "loggingingestion", "loggingsearch", "management_agent", "management_dashboard", "marketplace", "monitoring", "mysql", "nosql", "object_storage", "oce", "ocvp", "oda", "ons", "os_management", "resource_manager", "resource_search", "sch", "secrets", "streaming", "usage_api", "vault", "waas", "work_requests"
]



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RenameObjectDetails(object):
    """
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized,
    talk to an administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RenameObjectDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_name:
            The value to assign to the source_name property of this RenameObjectDetails.
        :type source_name: str

        :param new_name:
            The value to assign to the new_name property of this RenameObjectDetails.
        :type new_name: str

        :param src_obj_if_match_e_tag:
            The value to assign to the src_obj_if_match_e_tag property of this RenameObjectDetails.
        :type src_obj_if_match_e_tag: str

        :param new_obj_if_match_e_tag:
            The value to assign to the new_obj_if_match_e_tag property of this RenameObjectDetails.
        :type new_obj_if_match_e_tag: str

        :param new_obj_if_none_match_e_tag:
            The value to assign to the new_obj_if_none_match_e_tag property of this RenameObjectDetails.
        :type new_obj_if_none_match_e_tag: str

        """
        self.swagger_types = {
            'source_name': 'str',
            'new_name': 'str',
            'src_obj_if_match_e_tag': 'str',
            'new_obj_if_match_e_tag': 'str',
            'new_obj_if_none_match_e_tag': 'str'
        }

        self.attribute_map = {
            'source_name': 'sourceName',
            'new_name': 'newName',
            'src_obj_if_match_e_tag': 'srcObjIfMatchETag',
            'new_obj_if_match_e_tag': 'newObjIfMatchETag',
            'new_obj_if_none_match_e_tag': 'newObjIfNoneMatchETag'
        }

        self._source_name = None
        self._new_name = None
        self._src_obj_if_match_e_tag = None
        self._new_obj_if_match_e_tag = None
        self._new_obj_if_none_match_e_tag = None

    @property
    def source_name(self):
        """
        **[Required]** Gets the source_name of this RenameObjectDetails.
        The name of the source object to be renamed.


        :return: The source_name of this RenameObjectDetails.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this RenameObjectDetails.
        The name of the source object to be renamed.


        :param source_name: The source_name of this RenameObjectDetails.
        :type: str
        """
        self._source_name = source_name

    @property
    def new_name(self):
        """
        **[Required]** Gets the new_name of this RenameObjectDetails.
        The new name of the source object.


        :return: The new_name of this RenameObjectDetails.
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """
        Sets the new_name of this RenameObjectDetails.
        The new name of the source object.


        :param new_name: The new_name of this RenameObjectDetails.
        :type: str
        """
        self._new_name = new_name

    @property
    def src_obj_if_match_e_tag(self):
        """
        Gets the src_obj_if_match_e_tag of this RenameObjectDetails.
        The if-match entity tag (ETag) of the source object.


        :return: The src_obj_if_match_e_tag of this RenameObjectDetails.
        :rtype: str
        """
        return self._src_obj_if_match_e_tag

    @src_obj_if_match_e_tag.setter
    def src_obj_if_match_e_tag(self, src_obj_if_match_e_tag):
        """
        Sets the src_obj_if_match_e_tag of this RenameObjectDetails.
        The if-match entity tag (ETag) of the source object.


        :param src_obj_if_match_e_tag: The src_obj_if_match_e_tag of this RenameObjectDetails.
        :type: str
        """
        self._src_obj_if_match_e_tag = src_obj_if_match_e_tag

    @property
    def new_obj_if_match_e_tag(self):
        """
        Gets the new_obj_if_match_e_tag of this RenameObjectDetails.
        The if-match entity tag (ETag) of the new object.


        :return: The new_obj_if_match_e_tag of this RenameObjectDetails.
        :rtype: str
        """
        return self._new_obj_if_match_e_tag

    @new_obj_if_match_e_tag.setter
    def new_obj_if_match_e_tag(self, new_obj_if_match_e_tag):
        """
        Sets the new_obj_if_match_e_tag of this RenameObjectDetails.
        The if-match entity tag (ETag) of the new object.


        :param new_obj_if_match_e_tag: The new_obj_if_match_e_tag of this RenameObjectDetails.
        :type: str
        """
        self._new_obj_if_match_e_tag = new_obj_if_match_e_tag

    @property
    def new_obj_if_none_match_e_tag(self):
        """
        Gets the new_obj_if_none_match_e_tag of this RenameObjectDetails.
        The if-none-match entity tag (ETag) of the new object.


        :return: The new_obj_if_none_match_e_tag of this RenameObjectDetails.
        :rtype: str
        """
        return self._new_obj_if_none_match_e_tag

    @new_obj_if_none_match_e_tag.setter
    def new_obj_if_none_match_e_tag(self, new_obj_if_none_match_e_tag):
        """
        Sets the new_obj_if_none_match_e_tag of this RenameObjectDetails.
        The if-none-match entity tag (ETag) of the new object.


        :param new_obj_if_none_match_e_tag: The new_obj_if_none_match_e_tag of this RenameObjectDetails.
        :type: str
        """
        self._new_obj_if_none_match_e_tag = new_obj_if_none_match_e_tag

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IdentityStripeDetails(object):
    """
    Details of the identity stripe used for OceInstance
    """

    def __init__(self, **kwargs):
        """
        Initializes a new IdentityStripeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param service_name:
            The value to assign to the service_name property of this IdentityStripeDetails.
        :type service_name: str

        :param tenancy:
            The value to assign to the tenancy property of this IdentityStripeDetails.
        :type tenancy: str

        """
        self.swagger_types = {
            'service_name': 'str',
            'tenancy': 'str'
        }

        self.attribute_map = {
            'service_name': 'serviceName',
            'tenancy': 'tenancy'
        }

        self._service_name = None
        self._tenancy = None

    @property
    def service_name(self):
        """
        **[Required]** Gets the service_name of this IdentityStripeDetails.
        Name of the Identity Cloud Service instance in My Services to be used.
        Example: `secondstripe`


        :return: The service_name of this IdentityStripeDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this IdentityStripeDetails.
        Name of the Identity Cloud Service instance in My Services to be used.
        Example: `secondstripe`


        :param service_name: The service_name of this IdentityStripeDetails.
        :type: str
        """
        self._service_name = service_name

    @property
    def tenancy(self):
        """
        **[Required]** Gets the tenancy of this IdentityStripeDetails.
        Value of the Identity Cloud Service tenancy.
        Example: `idcs-8416ebdd0d674f84803f4193cce026e9`


        :return: The tenancy of this IdentityStripeDetails.
        :rtype: str
        """
        return self._tenancy

    @tenancy.setter
    def tenancy(self, tenancy):
        """
        Sets the tenancy of this IdentityStripeDetails.
        Value of the Identity Cloud Service tenancy.
        Example: `idcs-8416ebdd0d674f84803f4193cce026e9`


        :param tenancy: The tenancy of this IdentityStripeDetails.
        :type: str
        """
        self._tenancy = tenancy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Schema(object):
    """
    The table schema information as a JSON object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Schema object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param columns:
            The value to assign to the columns property of this Schema.
        :type columns: list[Column]

        :param primary_key:
            The value to assign to the primary_key property of this Schema.
        :type primary_key: list[str]

        :param shard_key:
            The value to assign to the shard_key property of this Schema.
        :type shard_key: list[str]

        :param ttl:
            The value to assign to the ttl property of this Schema.
        :type ttl: int

        """
        self.swagger_types = {
            'columns': 'list[Column]',
            'primary_key': 'list[str]',
            'shard_key': 'list[str]',
            'ttl': 'int'
        }

        self.attribute_map = {
            'columns': 'columns',
            'primary_key': 'primaryKey',
            'shard_key': 'shardKey',
            'ttl': 'ttl'
        }

        self._columns = None
        self._primary_key = None
        self._shard_key = None
        self._ttl = None

    @property
    def columns(self):
        """
        **[Required]** Gets the columns of this Schema.
        The columns of a table.


        :return: The columns of this Schema.
        :rtype: list[Column]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this Schema.
        The columns of a table.


        :param columns: The columns of this Schema.
        :type: list[Column]
        """
        self._columns = columns

    @property
    def primary_key(self):
        """
        **[Required]** Gets the primary_key of this Schema.
        A list of column names that make up a key.


        :return: The primary_key of this Schema.
        :rtype: list[str]
        """
        return self._primary_key

    @primary_key.setter
    def primary_key(self, primary_key):
        """
        Sets the primary_key of this Schema.
        A list of column names that make up a key.


        :param primary_key: The primary_key of this Schema.
        :type: list[str]
        """
        self._primary_key = primary_key

    @property
    def shard_key(self):
        """
        **[Required]** Gets the shard_key of this Schema.
        A list of column names that make up a key.


        :return: The shard_key of this Schema.
        :rtype: list[str]
        """
        return self._shard_key

    @shard_key.setter
    def shard_key(self, shard_key):
        """
        Sets the shard_key of this Schema.
        A list of column names that make up a key.


        :param shard_key: The shard_key of this Schema.
        :type: list[str]
        """
        self._shard_key = shard_key

    @property
    def ttl(self):
        """
        **[Required]** Gets the ttl of this Schema.
        The default Time-to-Live for the table, in days.


        :return: The ttl of this Schema.
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """
        Sets the ttl of this Schema.
        The default Time-to-Live for the table, in days.


        :param ttl: The ttl of this Schema.
        :type: int
        """
        self._ttl = ttl

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogEntryBatch(object):
    """
    A single batch of Log Entries.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogEntryBatch object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entries:
            The value to assign to the entries property of this LogEntryBatch.
        :type entries: list[LogEntry]

        :param source:
            The value to assign to the source property of this LogEntryBatch.
        :type source: str

        :param type:
            The value to assign to the type property of this LogEntryBatch.
        :type type: str

        :param subject:
            The value to assign to the subject property of this LogEntryBatch.
        :type subject: str

        :param defaultlogentrytime:
            The value to assign to the defaultlogentrytime property of this LogEntryBatch.
        :type defaultlogentrytime: datetime

        """
        self.swagger_types = {
            'entries': 'list[LogEntry]',
            'source': 'str',
            'type': 'str',
            'subject': 'str',
            'defaultlogentrytime': 'datetime'
        }

        self.attribute_map = {
            'entries': 'entries',
            'source': 'source',
            'type': 'type',
            'subject': 'subject',
            'defaultlogentrytime': 'defaultlogentrytime'
        }

        self._entries = None
        self._source = None
        self._type = None
        self._subject = None
        self._defaultlogentrytime = None

    @property
    def entries(self):
        """
        **[Required]** Gets the entries of this LogEntryBatch.
        List of data entries.


        :return: The entries of this LogEntryBatch.
        :rtype: list[LogEntry]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """
        Sets the entries of this LogEntryBatch.
        List of data entries.


        :param entries: The entries of this LogEntryBatch.
        :type: list[LogEntry]
        """
        self._entries = entries

    @property
    def source(self):
        """
        **[Required]** Gets the source of this LogEntryBatch.
        Source of the logs that generated the message. It could be the
        instance name, hostname or the source used to read the event.


        :return: The source of this LogEntryBatch.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this LogEntryBatch.
        Source of the logs that generated the message. It could be the
        instance name, hostname or the source used to read the event.


        :param source: The source of this LogEntryBatch.
        :type: str
        """
        self._source = source

    @property
    def type(self):
        """
        **[Required]** Gets the type of this LogEntryBatch.
        This field signifies the type of logs being ingested.
        For example: ServerA.requestLogs


        :return: The type of this LogEntryBatch.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this LogEntryBatch.
        This field signifies the type of logs being ingested.
        For example: ServerA.requestLogs


        :param type: The type of this LogEntryBatch.
        :type: str
        """
        self._type = type

    @property
    def subject(self):
        """
        Gets the subject of this LogEntryBatch.
        This optional field is useful for specifying the specific subresource
        or input file used to read the event.
        For example: \"/var/log/application.log\"


        :return: The subject of this LogEntryBatch.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this LogEntryBatch.
        This optional field is useful for specifying the specific subresource
        or input file used to read the event.
        For example: \"/var/log/application.log\"


        :param subject: The subject of this LogEntryBatch.
        :type: str
        """
        self._subject = subject

    @property
    def defaultlogentrytime(self):
        """
        **[Required]** Gets the defaultlogentrytime of this LogEntryBatch.
        The timestamp for all log entries in this request. This can be
        considered as the default timestamp for each entry, unless it is
        overwritten by the entry time. An RFC3339 formatted datetime
        string.


        :return: The defaultlogentrytime of this LogEntryBatch.
        :rtype: datetime
        """
        return self._defaultlogentrytime

    @defaultlogentrytime.setter
    def defaultlogentrytime(self, defaultlogentrytime):
        """
        Sets the defaultlogentrytime of this LogEntryBatch.
        The timestamp for all log entries in this request. This can be
        considered as the default timestamp for each entry, unless it is
        overwritten by the entry time. An RFC3339 formatted datetime
        string.


        :param defaultlogentrytime: The defaultlogentrytime of this LogEntryBatch.
        :type: datetime
        """
        self._defaultlogentrytime = defaultlogentrytime

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FastConnectProviderService(object):
    """
    A service offering from a supported provider. For more information,
    see `FastConnect Overview`__.

    __ https://docs.cloud.oracle.com/Content/Network/Concepts/fastconnect.htm
    """

    #: A constant which can be used with the private_peering_bgp_management property of a FastConnectProviderService.
    #: This constant has a value of "CUSTOMER_MANAGED"
    PRIVATE_PEERING_BGP_MANAGEMENT_CUSTOMER_MANAGED = "CUSTOMER_MANAGED"

    #: A constant which can be used with the private_peering_bgp_management property of a FastConnectProviderService.
    #: This constant has a value of "PROVIDER_MANAGED"
    PRIVATE_PEERING_BGP_MANAGEMENT_PROVIDER_MANAGED = "PROVIDER_MANAGED"

    #: A constant which can be used with the private_peering_bgp_management property of a FastConnectProviderService.
    #: This constant has a value of "ORACLE_MANAGED"
    PRIVATE_PEERING_BGP_MANAGEMENT_ORACLE_MANAGED = "ORACLE_MANAGED"

    #: A constant which can be used with the public_peering_bgp_management property of a FastConnectProviderService.
    #: This constant has a value of "CUSTOMER_MANAGED"
    PUBLIC_PEERING_BGP_MANAGEMENT_CUSTOMER_MANAGED = "CUSTOMER_MANAGED"

    #: A constant which can be used with the public_peering_bgp_management property of a FastConnectProviderService.
    #: This constant has a value of "PROVIDER_MANAGED"
    PUBLIC_PEERING_BGP_MANAGEMENT_PROVIDER_MANAGED = "PROVIDER_MANAGED"

    #: A constant which can be used with the public_peering_bgp_management property of a FastConnectProviderService.
    #: This constant has a value of "ORACLE_MANAGED"
    PUBLIC_PEERING_BGP_MANAGEMENT_ORACLE_MANAGED = "ORACLE_MANAGED"

    #: A constant which can be used with the supported_virtual_circuit_types property of a FastConnectProviderService.
    #: This constant has a value of "PUBLIC"
    SUPPORTED_VIRTUAL_CIRCUIT_TYPES_PUBLIC = "PUBLIC"

    #: A constant which can be used with the supported_virtual_circuit_types property of a FastConnectProviderService.
    #: This constant has a value of "PRIVATE"
    SUPPORTED_VIRTUAL_CIRCUIT_TYPES_PRIVATE = "PRIVATE"

    #: A constant which can be used with the customer_asn_management property of a FastConnectProviderService.
    #: This constant has a value of "CUSTOMER_MANAGED"
    CUSTOMER_ASN_MANAGEMENT_CUSTOMER_MANAGED = "CUSTOMER_MANAGED"

    #: A constant which can be used with the customer_asn_management property of a FastConnectProviderService.
    #: This constant has a value of "PROVIDER_MANAGED"
    CUSTOMER_ASN_MANAGEMENT_PROVIDER_MANAGED = "PROVIDER_MANAGED"

    #: A constant which can be used with the customer_asn_management property of a FastConnectProviderService.
    #: This constant has a value of "ORACLE_MANAGED"
    CUSTOMER_ASN_MANAGEMENT_ORACLE_MANAGED = "ORACLE_MANAGED"

    #: A constant which can be used with the provider_service_key_management property of a FastConnectProviderService.
    #: This constant has a value of "CUSTOMER_MANAGED"
    PROVIDER_SERVICE_KEY_MANAGEMENT_CUSTOMER_MANAGED = "CUSTOMER_MANAGED"

    #: A constant which can be used with the provider_service_key_management property of a FastConnectProviderService.
    #: This constant has a value of "PROVIDER_MANAGED"
    PROVIDER_SERVICE_KEY_MANAGEMENT_PROVIDER_MANAGED = "PROVIDER_MANAGED"

    #: A constant which can be used with the provider_service_key_management property of a FastConnectProviderService.
    #: This constant has a value of "ORACLE_MANAGED"
    PROVIDER_SERVICE_KEY_MANAGEMENT_ORACLE_MANAGED = "ORACLE_MANAGED"

    #: A constant which can be used with the bandwith_shape_management property of a FastConnectProviderService.
    #: This constant has a value of "CUSTOMER_MANAGED"
    BANDWITH_SHAPE_MANAGEMENT_CUSTOMER_MANAGED = "CUSTOMER_MANAGED"

    #: A constant which can be used with the bandwith_shape_management property of a FastConnectProviderService.
    #: This constant has a value of "PROVIDER_MANAGED"
    BANDWITH_SHAPE_MANAGEMENT_PROVIDER_MANAGED = "PROVIDER_MANAGED"

    #: A constant which can be used with the bandwith_shape_management property of a FastConnectProviderService.
    #: This constant has a value of "ORACLE_MANAGED"
    BANDWITH_SHAPE_MANAGEMENT_ORACLE_MANAGED = "ORACLE_MANAGED"

    #: A constant which can be used with the type property of a FastConnectProviderService.
    #: This constant has a value of "LAYER2"
    TYPE_LAYER2 = "LAYER2"

    #: A constant which can be used with the type property of a FastConnectProviderService.
    #: This constant has a value of "LAYER3"
    TYPE_LAYER3 = "LAYER3"

    def __init__(self, **kwargs):
        """
        Initializes a new FastConnectProviderService object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this FastConnectProviderService.
        :type description: str

        :param id:
            The value to assign to the id property of this FastConnectProviderService.
        :type id: str

        :param private_peering_bgp_management:
            The value to assign to the private_peering_bgp_management property of this FastConnectProviderService.
            Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type private_peering_bgp_management: str

        :param provider_name:
            The value to assign to the provider_name property of this FastConnectProviderService.
        :type provider_name: str

        :param provider_service_name:
            The value to assign to the provider_service_name property of this FastConnectProviderService.
        :type provider_service_name: str

        :param public_peering_bgp_management:
            The value to assign to the public_peering_bgp_management property of this FastConnectProviderService.
            Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type public_peering_bgp_management: str

        :param supported_virtual_circuit_types:
            The value to assign to the supported_virtual_circuit_types property of this FastConnectProviderService.
            Allowed values for items in this list are: "PUBLIC", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type supported_virtual_circuit_types: list[str]

        :param customer_asn_management:
            The value to assign to the customer_asn_management property of this FastConnectProviderService.
            Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type customer_asn_management: str

        :param provider_service_key_management:
            The value to assign to the provider_service_key_management property of this FastConnectProviderService.
            Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type provider_service_key_management: str

        :param bandwith_shape_management:
            The value to assign to the bandwith_shape_management property of this FastConnectProviderService.
            Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type bandwith_shape_management: str

        :param required_total_cross_connects:
            The value to assign to the required_total_cross_connects property of this FastConnectProviderService.
        :type required_total_cross_connects: int

        :param type:
            The value to assign to the type property of this FastConnectProviderService.
            Allowed values for this property are: "LAYER2", "LAYER3", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        """
        self.swagger_types = {
            'description': 'str',
            'id': 'str',
            'private_peering_bgp_management': 'str',
            'provider_name': 'str',
            'provider_service_name': 'str',
            'public_peering_bgp_management': 'str',
            'supported_virtual_circuit_types': 'list[str]',
            'customer_asn_management': 'str',
            'provider_service_key_management': 'str',
            'bandwith_shape_management': 'str',
            'required_total_cross_connects': 'int',
            'type': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'id': 'id',
            'private_peering_bgp_management': 'privatePeeringBgpManagement',
            'provider_name': 'providerName',
            'provider_service_name': 'providerServiceName',
            'public_peering_bgp_management': 'publicPeeringBgpManagement',
            'supported_virtual_circuit_types': 'supportedVirtualCircuitTypes',
            'customer_asn_management': 'customerAsnManagement',
            'provider_service_key_management': 'providerServiceKeyManagement',
            'bandwith_shape_management': 'bandwithShapeManagement',
            'required_total_cross_connects': 'requiredTotalCrossConnects',
            'type': 'type'
        }

        self._description = None
        self._id = None
        self._private_peering_bgp_management = None
        self._provider_name = None
        self._provider_service_name = None
        self._public_peering_bgp_management = None
        self._supported_virtual_circuit_types = None
        self._customer_asn_management = None
        self._provider_service_key_management = None
        self._bandwith_shape_management = None
        self._required_total_cross_connects = None
        self._type = None

    @property
    def description(self):
        """
        Gets the description of this FastConnectProviderService.
        The location of the provider's website or portal. This portal is where you can get information
        about the provider service, create a virtual circuit connection from the provider to Oracle
        Cloud Infrastructure, and retrieve your provider service key for that virtual circuit connection.

        Example: `https://example.com`


        :return: The description of this FastConnectProviderService.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FastConnectProviderService.
        The location of the provider's website or portal. This portal is where you can get information
        about the provider service, create a virtual circuit connection from the provider to Oracle
        Cloud Infrastructure, and retrieve your provider service key for that virtual circuit connection.

        Example: `https://example.com`


        :param description: The description of this FastConnectProviderService.
        :type: str
        """
        self._description = description

    @property
    def id(self):
        """
        **[Required]** Gets the id of this FastConnectProviderService.
        The OCID of the service offered by the provider.


        :return: The id of this FastConnectProviderService.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FastConnectProviderService.
        The OCID of the service offered by the provider.


        :param id: The id of this FastConnectProviderService.
        :type: str
        """
        self._id = id

    @property
    def private_peering_bgp_management(self):
        """
        **[Required]** Gets the private_peering_bgp_management of this FastConnectProviderService.
        Who is responsible for managing the private peering BGP information.

        Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The private_peering_bgp_management of this FastConnectProviderService.
        :rtype: str
        """
        return self._private_peering_bgp_management

    @private_peering_bgp_management.setter
    def private_peering_bgp_management(self, private_peering_bgp_management):
        """
        Sets the private_peering_bgp_management of this FastConnectProviderService.
        Who is responsible for managing the private peering BGP information.


        :param private_peering_bgp_management: The private_peering_bgp_management of this FastConnectProviderService.
        :type: str
        """
        allowed_values = ["CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED"]
        if not value_allowed_none_or_none_sentinel(private_peering_bgp_management, allowed_values):
            private_peering_bgp_management = 'UNKNOWN_ENUM_VALUE'
        self._private_peering_bgp_management = private_peering_bgp_management

    @property
    def provider_name(self):
        """
        **[Required]** Gets the provider_name of this FastConnectProviderService.
        The name of the provider.


        :return: The provider_name of this FastConnectProviderService.
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """
        Sets the provider_name of this FastConnectProviderService.
        The name of the provider.


        :param provider_name: The provider_name of this FastConnectProviderService.
        :type: str
        """
        self._provider_name = provider_name

    @property
    def provider_service_name(self):
        """
        **[Required]** Gets the provider_service_name of this FastConnectProviderService.
        The name of the service offered by the provider.


        :return: The provider_service_name of this FastConnectProviderService.
        :rtype: str
        """
        return self._provider_service_name

    @provider_service_name.setter
    def provider_service_name(self, provider_service_name):
        """
        Sets the provider_service_name of this FastConnectProviderService.
        The name of the service offered by the provider.


        :param provider_service_name: The provider_service_name of this FastConnectProviderService.
        :type: str
        """
        self._provider_service_name = provider_service_name

    @property
    def public_peering_bgp_management(self):
        """
        **[Required]** Gets the public_peering_bgp_management of this FastConnectProviderService.
        Who is responsible for managing the public peering BGP information.

        Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The public_peering_bgp_management of this FastConnectProviderService.
        :rtype: str
        """
        return self._public_peering_bgp_management

    @public_peering_bgp_management.setter
    def public_peering_bgp_management(self, public_peering_bgp_management):
        """
        Sets the public_peering_bgp_management of this FastConnectProviderService.
        Who is responsible for managing the public peering BGP information.


        :param public_peering_bgp_management: The public_peering_bgp_management of this FastConnectProviderService.
        :type: str
        """
        allowed_values = ["CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED"]
        if not value_allowed_none_or_none_sentinel(public_peering_bgp_management, allowed_values):
            public_peering_bgp_management = 'UNKNOWN_ENUM_VALUE'
        self._public_peering_bgp_management = public_peering_bgp_management

    @property
    def supported_virtual_circuit_types(self):
        """
        Gets the supported_virtual_circuit_types of this FastConnectProviderService.
        An array of virtual circuit types supported by this service.

        Allowed values for items in this list are: "PUBLIC", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The supported_virtual_circuit_types of this FastConnectProviderService.
        :rtype: list[str]
        """
        return self._supported_virtual_circuit_types

    @supported_virtual_circuit_types.setter
    def supported_virtual_circuit_types(self, supported_virtual_circuit_types):
        """
        Sets the supported_virtual_circuit_types of this FastConnectProviderService.
        An array of virtual circuit types supported by this service.


        :param supported_virtual_circuit_types: The supported_virtual_circuit_types of this FastConnectProviderService.
        :type: list[str]
        """
        allowed_values = ["PUBLIC", "PRIVATE"]
        if supported_virtual_circuit_types:
            supported_virtual_circuit_types[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in supported_virtual_circuit_types]
        self._supported_virtual_circuit_types = supported_virtual_circuit_types

    @property
    def customer_asn_management(self):
        """
        **[Required]** Gets the customer_asn_management of this FastConnectProviderService.
        Who is responsible for managing the ASN information for the network at the other end
        of the connection from Oracle.

        Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The customer_asn_management of this FastConnectProviderService.
        :rtype: str
        """
        return self._customer_asn_management

    @customer_asn_management.setter
    def customer_asn_management(self, customer_asn_management):
        """
        Sets the customer_asn_management of this FastConnectProviderService.
        Who is responsible for managing the ASN information for the network at the other end
        of the connection from Oracle.


        :param customer_asn_management: The customer_asn_management of this FastConnectProviderService.
        :type: str
        """
        allowed_values = ["CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED"]
        if not value_allowed_none_or_none_sentinel(customer_asn_management, allowed_values):
            customer_asn_management = 'UNKNOWN_ENUM_VALUE'
        self._customer_asn_management = customer_asn_management

    @property
    def provider_service_key_management(self):
        """
        **[Required]** Gets the provider_service_key_management of this FastConnectProviderService.
        Who is responsible for managing the provider service key.

        Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The provider_service_key_management of this FastConnectProviderService.
        :rtype: str
        """
        return self._provider_service_key_management

    @provider_service_key_management.setter
    def provider_service_key_management(self, provider_service_key_management):
        """
        Sets the provider_service_key_management of this FastConnectProviderService.
        Who is responsible for managing the provider service key.


        :param provider_service_key_management: The provider_service_key_management of this FastConnectProviderService.
        :type: str
        """
        allowed_values = ["CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED"]
        if not value_allowed_none_or_none_sentinel(provider_service_key_management, allowed_values):
            provider_service_key_management = 'UNKNOWN_ENUM_VALUE'
        self._provider_service_key_management = provider_service_key_management

    @property
    def bandwith_shape_management(self):
        """
        **[Required]** Gets the bandwith_shape_management of this FastConnectProviderService.
        Who is responsible for managing the virtual circuit bandwidth.

        Allowed values for this property are: "CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The bandwith_shape_management of this FastConnectProviderService.
        :rtype: str
        """
        return self._bandwith_shape_management

    @bandwith_shape_management.setter
    def bandwith_shape_management(self, bandwith_shape_management):
        """
        Sets the bandwith_shape_management of this FastConnectProviderService.
        Who is responsible for managing the virtual circuit bandwidth.


        :param bandwith_shape_management: The bandwith_shape_management of this FastConnectProviderService.
        :type: str
        """
        allowed_values = ["CUSTOMER_MANAGED", "PROVIDER_MANAGED", "ORACLE_MANAGED"]
        if not value_allowed_none_or_none_sentinel(bandwith_shape_management, allowed_values):
            bandwith_shape_management = 'UNKNOWN_ENUM_VALUE'
        self._bandwith_shape_management = bandwith_shape_management

    @property
    def required_total_cross_connects(self):
        """
        **[Required]** Gets the required_total_cross_connects of this FastConnectProviderService.
        Total number of cross-connect or cross-connect groups required for the virtual circuit.


        :return: The required_total_cross_connects of this FastConnectProviderService.
        :rtype: int
        """
        return self._required_total_cross_connects

    @required_total_cross_connects.setter
    def required_total_cross_connects(self, required_total_cross_connects):
        """
        Sets the required_total_cross_connects of this FastConnectProviderService.
        Total number of cross-connect or cross-connect groups required for the virtual circuit.


        :param required_total_cross_connects: The required_total_cross_connects of this FastConnectProviderService.
        :type: int
        """
        self._required_total_cross_connects = required_total_cross_connects

    @property
    def type(self):
        """
        **[Required]** Gets the type of this FastConnectProviderService.
        Provider service type.

        Allowed values for this property are: "LAYER2", "LAYER3", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this FastConnectProviderService.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this FastConnectProviderService.
        Provider service type.


        :param type: The type of this FastConnectProviderService.
        :type: str
        """
        allowed_values = ["LAYER2", "LAYER3"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WafBlockedRequest(object):
    """
    WafBlockedRequest model.
    """

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "PROTECTION_RULES"
    WAF_FEATURE_PROTECTION_RULES = "PROTECTION_RULES"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "JS_CHALLENGE"
    WAF_FEATURE_JS_CHALLENGE = "JS_CHALLENGE"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "ACCESS_RULES"
    WAF_FEATURE_ACCESS_RULES = "ACCESS_RULES"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "THREAT_FEEDS"
    WAF_FEATURE_THREAT_FEEDS = "THREAT_FEEDS"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "HUMAN_INTERACTION_CHALLENGE"
    WAF_FEATURE_HUMAN_INTERACTION_CHALLENGE = "HUMAN_INTERACTION_CHALLENGE"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "DEVICE_FINGERPRINT_CHALLENGE"
    WAF_FEATURE_DEVICE_FINGERPRINT_CHALLENGE = "DEVICE_FINGERPRINT_CHALLENGE"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "CAPTCHA"
    WAF_FEATURE_CAPTCHA = "CAPTCHA"

    #: A constant which can be used with the waf_feature property of a WafBlockedRequest.
    #: This constant has a value of "ADDRESS_RATE_LIMITING"
    WAF_FEATURE_ADDRESS_RATE_LIMITING = "ADDRESS_RATE_LIMITING"

    def __init__(self, **kwargs):
        """
        Initializes a new WafBlockedRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_observed:
            The value to assign to the time_observed property of this WafBlockedRequest.
        :type time_observed: datetime

        :param time_range_in_seconds:
            The value to assign to the time_range_in_seconds property of this WafBlockedRequest.
        :type time_range_in_seconds: int

        :param waf_feature:
            The value to assign to the waf_feature property of this WafBlockedRequest.
            Allowed values for this property are: "PROTECTION_RULES", "JS_CHALLENGE", "ACCESS_RULES", "THREAT_FEEDS", "HUMAN_INTERACTION_CHALLENGE", "DEVICE_FINGERPRINT_CHALLENGE", "CAPTCHA", "ADDRESS_RATE_LIMITING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type waf_feature: str

        :param count:
            The value to assign to the count property of this WafBlockedRequest.
        :type count: int

        """
        self.swagger_types = {
            'time_observed': 'datetime',
            'time_range_in_seconds': 'int',
            'waf_feature': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'time_observed': 'timeObserved',
            'time_range_in_seconds': 'timeRangeInSeconds',
            'waf_feature': 'wafFeature',
            'count': 'count'
        }

        self._time_observed = None
        self._time_range_in_seconds = None
        self._waf_feature = None
        self._count = None

    @property
    def time_observed(self):
        """
        Gets the time_observed of this WafBlockedRequest.
        The date and time the blocked requests were observed, expressed in RFC 3339 timestamp format.


        :return: The time_observed of this WafBlockedRequest.
        :rtype: datetime
        """
        return self._time_observed

    @time_observed.setter
    def time_observed(self, time_observed):
        """
        Sets the time_observed of this WafBlockedRequest.
        The date and time the blocked requests were observed, expressed in RFC 3339 timestamp format.


        :param time_observed: The time_observed of this WafBlockedRequest.
        :type: datetime
        """
        self._time_observed = time_observed

    @property
    def time_range_in_seconds(self):
        """
        Gets the time_range_in_seconds of this WafBlockedRequest.
        The number of seconds the data covers.


        :return: The time_range_in_seconds of this WafBlockedRequest.
        :rtype: int
        """
        return self._time_range_in_seconds

    @time_range_in_seconds.setter
    def time_range_in_seconds(self, time_range_in_seconds):
        """
        Sets the time_range_in_seconds of this WafBlockedRequest.
        The number of seconds the data covers.


        :param time_range_in_seconds: The time_range_in_seconds of this WafBlockedRequest.
        :type: int
        """
        self._time_range_in_seconds = time_range_in_seconds

    @property
    def waf_feature(self):
        """
        Gets the waf_feature of this WafBlockedRequest.
        The specific Web Application Firewall feature that blocked the requests, such as JavaScript Challenge or Access Control.

        Allowed values for this property are: "PROTECTION_RULES", "JS_CHALLENGE", "ACCESS_RULES", "THREAT_FEEDS", "HUMAN_INTERACTION_CHALLENGE", "DEVICE_FINGERPRINT_CHALLENGE", "CAPTCHA", "ADDRESS_RATE_LIMITING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The waf_feature of this WafBlockedRequest.
        :rtype: str
        """
        return self._waf_feature

    @waf_feature.setter
    def waf_feature(self, waf_feature):
        """
        Sets the waf_feature of this WafBlockedRequest.
        The specific Web Application Firewall feature that blocked the requests, such as JavaScript Challenge or Access Control.


        :param waf_feature: The waf_feature of this WafBlockedRequest.
        :type: str
        """
        allowed_values = ["PROTECTION_RULES", "JS_CHALLENGE", "ACCESS_RULES", "THREAT_FEEDS", "HUMAN_INTERACTION_CHALLENGE", "DEVICE_FINGERPRINT_CHALLENGE", "CAPTCHA", "ADDRESS_RATE_LIMITING"]
        if not value_allowed_none_or_none_sentinel(waf_feature, allowed_values):
            waf_feature = 'UNKNOWN_ENUM_VALUE'
        self._waf_feature = waf_feature

    @property
    def count(self):
        """
        Gets the count of this WafBlockedRequest.
        The count of blocked requests.


        :return: The count of this WafBlockedRequest.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this WafBlockedRequest.
        The count of blocked requests.


        :param count: The count of this WafBlockedRequest.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryParameterTransformationPolicy(object):
    """
    A set of transformations to apply to query parameters that pass through the gateway.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryParameterTransformationPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param set_query_parameters:
            The value to assign to the set_query_parameters property of this QueryParameterTransformationPolicy.
        :type set_query_parameters: SetQueryParameterPolicy

        :param rename_query_parameters:
            The value to assign to the rename_query_parameters property of this QueryParameterTransformationPolicy.
        :type rename_query_parameters: RenameQueryParameterPolicy

        :param filter_query_parameters:
            The value to assign to the filter_query_parameters property of this QueryParameterTransformationPolicy.
        :type filter_query_parameters: FilterQueryParameterPolicy

        """
        self.swagger_types = {
            'set_query_parameters': 'SetQueryParameterPolicy',
            'rename_query_parameters': 'RenameQueryParameterPolicy',
            'filter_query_parameters': 'FilterQueryParameterPolicy'
        }

        self.attribute_map = {
            'set_query_parameters': 'setQueryParameters',
            'rename_query_parameters': 'renameQueryParameters',
            'filter_query_parameters': 'filterQueryParameters'
        }

        self._set_query_parameters = None
        self._rename_query_parameters = None
        self._filter_query_parameters = None

    @property
    def set_query_parameters(self):
        """
        Gets the set_query_parameters of this QueryParameterTransformationPolicy.

        :return: The set_query_parameters of this QueryParameterTransformationPolicy.
        :rtype: SetQueryParameterPolicy
        """
        return self._set_query_parameters

    @set_query_parameters.setter
    def set_query_parameters(self, set_query_parameters):
        """
        Sets the set_query_parameters of this QueryParameterTransformationPolicy.

        :param set_query_parameters: The set_query_parameters of this QueryParameterTransformationPolicy.
        :type: SetQueryParameterPolicy
        """
        self._set_query_parameters = set_query_parameters

    @property
    def rename_query_parameters(self):
        """
        Gets the rename_query_parameters of this QueryParameterTransformationPolicy.

        :return: The rename_query_parameters of this QueryParameterTransformationPolicy.
        :rtype: RenameQueryParameterPolicy
        """
        return self._rename_query_parameters

    @rename_query_parameters.setter
    def rename_query_parameters(self, rename_query_parameters):
        """
        Sets the rename_query_parameters of this QueryParameterTransformationPolicy.

        :param rename_query_parameters: The rename_query_parameters of this QueryParameterTransformationPolicy.
        :type: RenameQueryParameterPolicy
        """
        self._rename_query_parameters = rename_query_parameters

    @property
    def filter_query_parameters(self):
        """
        Gets the filter_query_parameters of this QueryParameterTransformationPolicy.

        :return: The filter_query_parameters of this QueryParameterTransformationPolicy.
        :rtype: FilterQueryParameterPolicy
        """
        return self._filter_query_parameters

    @filter_query_parameters.setter
    def filter_query_parameters(self, filter_query_parameters):
        """
        Sets the filter_query_parameters of this QueryParameterTransformationPolicy.

        :param filter_query_parameters: The filter_query_parameters of this QueryParameterTransformationPolicy.
        :type: FilterQueryParameterPolicy
        """
        self._filter_query_parameters = filter_query_parameters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IdentityProviderGroupSummary(object):
    """
    A group created in an identity provider that can be mapped to a group in OCI
    """

    def __init__(self, **kwargs):
        """
        Initializes a new IdentityProviderGroupSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this IdentityProviderGroupSummary.
        :type id: str

        :param identity_provider_id:
            The value to assign to the identity_provider_id property of this IdentityProviderGroupSummary.
        :type identity_provider_id: str

        :param display_name:
            The value to assign to the display_name property of this IdentityProviderGroupSummary.
        :type display_name: str

        :param name:
            The value to assign to the name property of this IdentityProviderGroupSummary.
        :type name: str

        :param external_identifier:
            The value to assign to the external_identifier property of this IdentityProviderGroupSummary.
        :type external_identifier: str

        :param time_created:
            The value to assign to the time_created property of this IdentityProviderGroupSummary.
        :type time_created: datetime

        :param time_modified:
            The value to assign to the time_modified property of this IdentityProviderGroupSummary.
        :type time_modified: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'identity_provider_id': 'str',
            'display_name': 'str',
            'name': 'str',
            'external_identifier': 'str',
            'time_created': 'datetime',
            'time_modified': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'identity_provider_id': 'identityProviderId',
            'display_name': 'displayName',
            'name': 'name',
            'external_identifier': 'externalIdentifier',
            'time_created': 'timeCreated',
            'time_modified': 'timeModified'
        }

        self._id = None
        self._identity_provider_id = None
        self._display_name = None
        self._name = None
        self._external_identifier = None
        self._time_created = None
        self._time_modified = None

    @property
    def id(self):
        """
        Gets the id of this IdentityProviderGroupSummary.
        The OCID of the `IdentityProviderGroup`.


        :return: The id of this IdentityProviderGroupSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IdentityProviderGroupSummary.
        The OCID of the `IdentityProviderGroup`.


        :param id: The id of this IdentityProviderGroupSummary.
        :type: str
        """
        self._id = id

    @property
    def identity_provider_id(self):
        """
        Gets the identity_provider_id of this IdentityProviderGroupSummary.
        The OCID of the `IdentityProvider` this group belongs to.


        :return: The identity_provider_id of this IdentityProviderGroupSummary.
        :rtype: str
        """
        return self._identity_provider_id

    @identity_provider_id.setter
    def identity_provider_id(self, identity_provider_id):
        """
        Sets the identity_provider_id of this IdentityProviderGroupSummary.
        The OCID of the `IdentityProvider` this group belongs to.


        :param identity_provider_id: The identity_provider_id of this IdentityProviderGroupSummary.
        :type: str
        """
        self._identity_provider_id = identity_provider_id

    @property
    def display_name(self):
        """
        Gets the display_name of this IdentityProviderGroupSummary.
        Display name of the group


        :return: The display_name of this IdentityProviderGroupSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this IdentityProviderGroupSummary.
        Display name of the group


        :param display_name: The display_name of this IdentityProviderGroupSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def name(self):
        """
        Gets the name of this IdentityProviderGroupSummary.
        Display name of the group


        :return: The name of this IdentityProviderGroupSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IdentityProviderGroupSummary.
        Display name of the group


        :param name: The name of this IdentityProviderGroupSummary.
        :type: str
        """
        self._name = name

    @property
    def external_identifier(self):
        """
        Gets the external_identifier of this IdentityProviderGroupSummary.
        Identifier of the group in the identity provider


        :return: The external_identifier of this IdentityProviderGroupSummary.
        :rtype: str
        """
        return self._external_identifier

    @external_identifier.setter
    def external_identifier(self, external_identifier):
        """
        Sets the external_identifier of this IdentityProviderGroupSummary.
        Identifier of the group in the identity provider


        :param external_identifier: The external_identifier of this IdentityProviderGroupSummary.
        :type: str
        """
        self._external_identifier = external_identifier

    @property
    def time_created(self):
        """
        Gets the time_created of this IdentityProviderGroupSummary.
        Date and time the `IdentityProviderGroup` was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this IdentityProviderGroupSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this IdentityProviderGroupSummary.
        Date and time the `IdentityProviderGroup` was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this IdentityProviderGroupSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_modified(self):
        """
        Gets the time_modified of this IdentityProviderGroupSummary.
        Date and time the `IdentityProviderGroup` was last modified, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_modified of this IdentityProviderGroupSummary.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this IdentityProviderGroupSummary.
        Date and time the `IdentityProviderGroup` was last modified, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_modified: The time_modified of this IdentityProviderGroupSummary.
        :type: datetime
        """
        self._time_modified = time_modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDatabaseFromBackupDetails(object):
    """
    CreateDatabaseFromBackupDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDatabaseFromBackupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param backup_id:
            The value to assign to the backup_id property of this CreateDatabaseFromBackupDetails.
        :type backup_id: str

        :param backup_tde_password:
            The value to assign to the backup_tde_password property of this CreateDatabaseFromBackupDetails.
        :type backup_tde_password: str

        :param admin_password:
            The value to assign to the admin_password property of this CreateDatabaseFromBackupDetails.
        :type admin_password: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this CreateDatabaseFromBackupDetails.
        :type db_unique_name: str

        :param db_name:
            The value to assign to the db_name property of this CreateDatabaseFromBackupDetails.
        :type db_name: str

        """
        self.swagger_types = {
            'backup_id': 'str',
            'backup_tde_password': 'str',
            'admin_password': 'str',
            'db_unique_name': 'str',
            'db_name': 'str'
        }

        self.attribute_map = {
            'backup_id': 'backupId',
            'backup_tde_password': 'backupTDEPassword',
            'admin_password': 'adminPassword',
            'db_unique_name': 'dbUniqueName',
            'db_name': 'dbName'
        }

        self._backup_id = None
        self._backup_tde_password = None
        self._admin_password = None
        self._db_unique_name = None
        self._db_name = None

    @property
    def backup_id(self):
        """
        **[Required]** Gets the backup_id of this CreateDatabaseFromBackupDetails.
        The backup `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The backup_id of this CreateDatabaseFromBackupDetails.
        :rtype: str
        """
        return self._backup_id

    @backup_id.setter
    def backup_id(self, backup_id):
        """
        Sets the backup_id of this CreateDatabaseFromBackupDetails.
        The backup `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param backup_id: The backup_id of this CreateDatabaseFromBackupDetails.
        :type: str
        """
        self._backup_id = backup_id

    @property
    def backup_tde_password(self):
        """
        **[Required]** Gets the backup_tde_password of this CreateDatabaseFromBackupDetails.
        The password to open the TDE wallet.


        :return: The backup_tde_password of this CreateDatabaseFromBackupDetails.
        :rtype: str
        """
        return self._backup_tde_password

    @backup_tde_password.setter
    def backup_tde_password(self, backup_tde_password):
        """
        Sets the backup_tde_password of this CreateDatabaseFromBackupDetails.
        The password to open the TDE wallet.


        :param backup_tde_password: The backup_tde_password of this CreateDatabaseFromBackupDetails.
        :type: str
        """
        self._backup_tde_password = backup_tde_password

    @property
    def admin_password(self):
        """
        **[Required]** Gets the admin_password of this CreateDatabaseFromBackupDetails.
        A strong password for SYS, SYSTEM, PDB Admin and TDE Wallet. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :return: The admin_password of this CreateDatabaseFromBackupDetails.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this CreateDatabaseFromBackupDetails.
        A strong password for SYS, SYSTEM, PDB Admin and TDE Wallet. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.


        :param admin_password: The admin_password of this CreateDatabaseFromBackupDetails.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this CreateDatabaseFromBackupDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :return: The db_unique_name of this CreateDatabaseFromBackupDetails.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this CreateDatabaseFromBackupDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :param db_unique_name: The db_unique_name of this CreateDatabaseFromBackupDetails.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def db_name(self):
        """
        Gets the db_name of this CreateDatabaseFromBackupDetails.
        The display name of the database to be created from the backup. It must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.


        :return: The db_name of this CreateDatabaseFromBackupDetails.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this CreateDatabaseFromBackupDetails.
        The display name of the database to be created from the backup. It must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.


        :param db_name: The db_name of this CreateDatabaseFromBackupDetails.
        :type: str
        """
        self._db_name = db_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WaasPolicy(object):
    """
    The details of a Web Application Acceleration and Security (WAAS) policy. A policy describes how the WAAS service should operate for the configured web application.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the lifecycle_state property of a WaasPolicy.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a WaasPolicy.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a WaasPolicy.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a WaasPolicy.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a WaasPolicy.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a WaasPolicy.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new WaasPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this WaasPolicy.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this WaasPolicy.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this WaasPolicy.
        :type display_name: str

        :param domain:
            The value to assign to the domain property of this WaasPolicy.
        :type domain: str

        :param additional_domains:
            The value to assign to the additional_domains property of this WaasPolicy.
        :type additional_domains: list[str]

        :param cname:
            The value to assign to the cname property of this WaasPolicy.
        :type cname: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this WaasPolicy.
            Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "UPDATING", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this WaasPolicy.
        :type time_created: datetime

        :param origins:
            The value to assign to the origins property of this WaasPolicy.
        :type origins: dict(str, Origin)

        :param origin_groups:
            The value to assign to the origin_groups property of this WaasPolicy.
        :type origin_groups: dict(str, OriginGroup)

        :param policy_config:
            The value to assign to the policy_config property of this WaasPolicy.
        :type policy_config: PolicyConfig

        :param waf_config:
            The value to assign to the waf_config property of this WaasPolicy.
        :type waf_config: WafConfig

        :param freeform_tags:
            The value to assign to the freeform_tags property of this WaasPolicy.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this WaasPolicy.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'domain': 'str',
            'additional_domains': 'list[str]',
            'cname': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'origins': 'dict(str, Origin)',
            'origin_groups': 'dict(str, OriginGroup)',
            'policy_config': 'PolicyConfig',
            'waf_config': 'WafConfig',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'domain': 'domain',
            'additional_domains': 'additionalDomains',
            'cname': 'cname',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'origins': 'origins',
            'origin_groups': 'originGroups',
            'policy_config': 'policyConfig',
            'waf_config': 'wafConfig',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._domain = None
        self._additional_domains = None
        self._cname = None
        self._lifecycle_state = None
        self._time_created = None
        self._origins = None
        self._origin_groups = None
        self._policy_config = None
        self._waf_config = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        Gets the id of this WaasPolicy.
        The `OCID`__ of the WAAS policy.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this WaasPolicy.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WaasPolicy.
        The `OCID`__ of the WAAS policy.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this WaasPolicy.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this WaasPolicy.
        The `OCID`__ of the WAAS policy's compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this WaasPolicy.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this WaasPolicy.
        The `OCID`__ of the WAAS policy's compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this WaasPolicy.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this WaasPolicy.
        The user-friendly name of the WAAS policy. The name can be changed and does not need to be unique.


        :return: The display_name of this WaasPolicy.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this WaasPolicy.
        The user-friendly name of the WAAS policy. The name can be changed and does not need to be unique.


        :param display_name: The display_name of this WaasPolicy.
        :type: str
        """
        self._display_name = display_name

    @property
    def domain(self):
        """
        Gets the domain of this WaasPolicy.
        The web application domain that the WAAS policy protects.


        :return: The domain of this WaasPolicy.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this WaasPolicy.
        The web application domain that the WAAS policy protects.


        :param domain: The domain of this WaasPolicy.
        :type: str
        """
        self._domain = domain

    @property
    def additional_domains(self):
        """
        Gets the additional_domains of this WaasPolicy.
        An array of additional domains for this web application.


        :return: The additional_domains of this WaasPolicy.
        :rtype: list[str]
        """
        return self._additional_domains

    @additional_domains.setter
    def additional_domains(self, additional_domains):
        """
        Sets the additional_domains of this WaasPolicy.
        An array of additional domains for this web application.


        :param additional_domains: The additional_domains of this WaasPolicy.
        :type: list[str]
        """
        self._additional_domains = additional_domains

    @property
    def cname(self):
        """
        Gets the cname of this WaasPolicy.
        The CNAME record to add to your DNS configuration to route traffic for the domain, and all additional domains, through the WAF.


        :return: The cname of this WaasPolicy.
        :rtype: str
        """
        return self._cname

    @cname.setter
    def cname(self, cname):
        """
        Sets the cname of this WaasPolicy.
        The CNAME record to add to your DNS configuration to route traffic for the domain, and all additional domains, through the WAF.


        :param cname: The cname of this WaasPolicy.
        :type: str
        """
        self._cname = cname

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this WaasPolicy.
        The current lifecycle state of the WAAS policy.

        Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "UPDATING", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this WaasPolicy.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this WaasPolicy.
        The current lifecycle state of the WAAS policy.


        :param lifecycle_state: The lifecycle_state of this WaasPolicy.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "FAILED", "UPDATING", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this WaasPolicy.
        The date and time the policy was created, expressed in RFC 3339 timestamp format.


        :return: The time_created of this WaasPolicy.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this WaasPolicy.
        The date and time the policy was created, expressed in RFC 3339 timestamp format.


        :param time_created: The time_created of this WaasPolicy.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def origins(self):
        """
        Gets the origins of this WaasPolicy.
        A map of host servers (origins) and their keys for the web application. Origin keys are used to associate origins to specific protection rules. The key should be a user-friendly name for the host. **Examples:** `primary` or `secondary`.


        :return: The origins of this WaasPolicy.
        :rtype: dict(str, Origin)
        """
        return self._origins

    @origins.setter
    def origins(self, origins):
        """
        Sets the origins of this WaasPolicy.
        A map of host servers (origins) and their keys for the web application. Origin keys are used to associate origins to specific protection rules. The key should be a user-friendly name for the host. **Examples:** `primary` or `secondary`.


        :param origins: The origins of this WaasPolicy.
        :type: dict(str, Origin)
        """
        self._origins = origins

    @property
    def origin_groups(self):
        """
        Gets the origin_groups of this WaasPolicy.
        The map of origin groups and their keys used to associate origins to the `wafConfig`. Origin groups allow you to apply weights to groups of origins for load balancing purposes. Origins with higher weights will receive larger proportions of client requests.


        :return: The origin_groups of this WaasPolicy.
        :rtype: dict(str, OriginGroup)
        """
        return self._origin_groups

    @origin_groups.setter
    def origin_groups(self, origin_groups):
        """
        Sets the origin_groups of this WaasPolicy.
        The map of origin groups and their keys used to associate origins to the `wafConfig`. Origin groups allow you to apply weights to groups of origins for load balancing purposes. Origins with higher weights will receive larger proportions of client requests.


        :param origin_groups: The origin_groups of this WaasPolicy.
        :type: dict(str, OriginGroup)
        """
        self._origin_groups = origin_groups

    @property
    def policy_config(self):
        """
        Gets the policy_config of this WaasPolicy.

        :return: The policy_config of this WaasPolicy.
        :rtype: PolicyConfig
        """
        return self._policy_config

    @policy_config.setter
    def policy_config(self, policy_config):
        """
        Sets the policy_config of this WaasPolicy.

        :param policy_config: The policy_config of this WaasPolicy.
        :type: PolicyConfig
        """
        self._policy_config = policy_config

    @property
    def waf_config(self):
        """
        Gets the waf_config of this WaasPolicy.

        :return: The waf_config of this WaasPolicy.
        :rtype: WafConfig
        """
        return self._waf_config

    @waf_config.setter
    def waf_config(self, waf_config):
        """
        Sets the waf_config of this WaasPolicy.

        :param waf_config: The waf_config of this WaasPolicy.
        :type: WafConfig
        """
        self._waf_config = waf_config

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this WaasPolicy.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this WaasPolicy.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this WaasPolicy.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this WaasPolicy.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this WaasPolicy.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this WaasPolicy.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this WaasPolicy.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this WaasPolicy.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdatePrivateEndpointDetails(object):
    """
    The update private endpoint details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdatePrivateEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdatePrivateEndpointDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param description:
            The value to assign to the description property of this UpdatePrivateEndpointDetails.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this UpdatePrivateEndpointDetails.
        :type display_name: str

        :param dns_zones:
            The value to assign to the dns_zones property of this UpdatePrivateEndpointDetails.
        :type dns_zones: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdatePrivateEndpointDetails.
        :type freeform_tags: dict(str, str)

        :param max_host_count:
            The value to assign to the max_host_count property of this UpdatePrivateEndpointDetails.
        :type max_host_count: int

        :param nsg_ids:
            The value to assign to the nsg_ids property of this UpdatePrivateEndpointDetails.
        :type nsg_ids: list[str]

        """
        self.swagger_types = {
            'defined_tags': 'dict(str, dict(str, object))',
            'description': 'str',
            'display_name': 'str',
            'dns_zones': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'max_host_count': 'int',
            'nsg_ids': 'list[str]'
        }

        self.attribute_map = {
            'defined_tags': 'definedTags',
            'description': 'description',
            'display_name': 'displayName',
            'dns_zones': 'dnsZones',
            'freeform_tags': 'freeformTags',
            'max_host_count': 'maxHostCount',
            'nsg_ids': 'nsgIds'
        }

        self._defined_tags = None
        self._description = None
        self._display_name = None
        self._dns_zones = None
        self._freeform_tags = None
        self._max_host_count = None
        self._nsg_ids = None

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdatePrivateEndpointDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdatePrivateEndpointDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdatePrivateEndpointDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdatePrivateEndpointDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def description(self):
        """
        Gets the description of this UpdatePrivateEndpointDetails.
        A user-friendly description. Avoid entering confidential information.


        :return: The description of this UpdatePrivateEndpointDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdatePrivateEndpointDetails.
        A user-friendly description. Avoid entering confidential information.


        :param description: The description of this UpdatePrivateEndpointDetails.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdatePrivateEndpointDetails.
        A user-friendly name. It does not have to be unique. Avoid entering confidential information.


        :return: The display_name of this UpdatePrivateEndpointDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdatePrivateEndpointDetails.
        A user-friendly name. It does not have to be unique. Avoid entering confidential information.


        :param display_name: The display_name of this UpdatePrivateEndpointDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def dns_zones(self):
        """
        Gets the dns_zones of this UpdatePrivateEndpointDetails.
        An array of DNS zone names.
        Example: `[ \"app.examplecorp.com\", \"app.examplecorp2.com\" ]`


        :return: The dns_zones of this UpdatePrivateEndpointDetails.
        :rtype: list[str]
        """
        return self._dns_zones

    @dns_zones.setter
    def dns_zones(self, dns_zones):
        """
        Sets the dns_zones of this UpdatePrivateEndpointDetails.
        An array of DNS zone names.
        Example: `[ \"app.examplecorp.com\", \"app.examplecorp2.com\" ]`


        :param dns_zones: The dns_zones of this UpdatePrivateEndpointDetails.
        :type: list[str]
        """
        self._dns_zones = dns_zones

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdatePrivateEndpointDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdatePrivateEndpointDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdatePrivateEndpointDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdatePrivateEndpointDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def max_host_count(self):
        """
        Gets the max_host_count of this UpdatePrivateEndpointDetails.
        The maximum number of hosts to be accessed through the private endpoint. This value is used
        to calculate the relevant CIDR block and should be a multiple of 256.  If the value is not a
        multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up
        to 512.


        :return: The max_host_count of this UpdatePrivateEndpointDetails.
        :rtype: int
        """
        return self._max_host_count

    @max_host_count.setter
    def max_host_count(self, max_host_count):
        """
        Sets the max_host_count of this UpdatePrivateEndpointDetails.
        The maximum number of hosts to be accessed through the private endpoint. This value is used
        to calculate the relevant CIDR block and should be a multiple of 256.  If the value is not a
        multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up
        to 512.


        :param max_host_count: The max_host_count of this UpdatePrivateEndpointDetails.
        :type: int
        """
        self._max_host_count = max_host_count

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this UpdatePrivateEndpointDetails.
        An array of network security group OCIDs.


        :return: The nsg_ids of this UpdatePrivateEndpointDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this UpdatePrivateEndpointDetails.
        An array of network security group OCIDs.


        :param nsg_ids: The nsg_ids of this UpdatePrivateEndpointDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HumanInteractionChallenge(object):
    """
    The human interaction challenge settings. The human interaction challenge checks various event listeners in the user's browser to determine if there is a human user making a request.
    """

    #: A constant which can be used with the action property of a HumanInteractionChallenge.
    #: This constant has a value of "DETECT"
    ACTION_DETECT = "DETECT"

    #: A constant which can be used with the action property of a HumanInteractionChallenge.
    #: This constant has a value of "BLOCK"
    ACTION_BLOCK = "BLOCK"

    def __init__(self, **kwargs):
        """
        Initializes a new HumanInteractionChallenge object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_enabled:
            The value to assign to the is_enabled property of this HumanInteractionChallenge.
        :type is_enabled: bool

        :param action:
            The value to assign to the action property of this HumanInteractionChallenge.
            Allowed values for this property are: "DETECT", "BLOCK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        :param failure_threshold:
            The value to assign to the failure_threshold property of this HumanInteractionChallenge.
        :type failure_threshold: int

        :param action_expiration_in_seconds:
            The value to assign to the action_expiration_in_seconds property of this HumanInteractionChallenge.
        :type action_expiration_in_seconds: int

        :param failure_threshold_expiration_in_seconds:
            The value to assign to the failure_threshold_expiration_in_seconds property of this HumanInteractionChallenge.
        :type failure_threshold_expiration_in_seconds: int

        :param interaction_threshold:
            The value to assign to the interaction_threshold property of this HumanInteractionChallenge.
        :type interaction_threshold: int

        :param recording_period_in_seconds:
            The value to assign to the recording_period_in_seconds property of this HumanInteractionChallenge.
        :type recording_period_in_seconds: int

        :param set_http_header:
            The value to assign to the set_http_header property of this HumanInteractionChallenge.
        :type set_http_header: Header

        :param challenge_settings:
            The value to assign to the challenge_settings property of this HumanInteractionChallenge.
        :type challenge_settings: BlockChallengeSettings

        :param is_nat_enabled:
            The value to assign to the is_nat_enabled property of this HumanInteractionChallenge.
        :type is_nat_enabled: bool

        """
        self.swagger_types = {
            'is_enabled': 'bool',
            'action': 'str',
            'failure_threshold': 'int',
            'action_expiration_in_seconds': 'int',
            'failure_threshold_expiration_in_seconds': 'int',
            'interaction_threshold': 'int',
            'recording_period_in_seconds': 'int',
            'set_http_header': 'Header',
            'challenge_settings': 'BlockChallengeSettings',
            'is_nat_enabled': 'bool'
        }

        self.attribute_map = {
            'is_enabled': 'isEnabled',
            'action': 'action',
            'failure_threshold': 'failureThreshold',
            'action_expiration_in_seconds': 'actionExpirationInSeconds',
            'failure_threshold_expiration_in_seconds': 'failureThresholdExpirationInSeconds',
            'interaction_threshold': 'interactionThreshold',
            'recording_period_in_seconds': 'recordingPeriodInSeconds',
            'set_http_header': 'setHttpHeader',
            'challenge_settings': 'challengeSettings',
            'is_nat_enabled': 'isNatEnabled'
        }

        self._is_enabled = None
        self._action = None
        self._failure_threshold = None
        self._action_expiration_in_seconds = None
        self._failure_threshold_expiration_in_seconds = None
        self._interaction_threshold = None
        self._recording_period_in_seconds = None
        self._set_http_header = None
        self._challenge_settings = None
        self._is_nat_enabled = None

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this HumanInteractionChallenge.
        Enables or disables the human interaction challenge Web Application Firewall feature.


        :return: The is_enabled of this HumanInteractionChallenge.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this HumanInteractionChallenge.
        Enables or disables the human interaction challenge Web Application Firewall feature.


        :param is_enabled: The is_enabled of this HumanInteractionChallenge.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def action(self):
        """
        Gets the action of this HumanInteractionChallenge.
        The action to take against requests from detected bots. If unspecified, defaults to `DETECT`.

        Allowed values for this property are: "DETECT", "BLOCK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this HumanInteractionChallenge.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this HumanInteractionChallenge.
        The action to take against requests from detected bots. If unspecified, defaults to `DETECT`.


        :param action: The action of this HumanInteractionChallenge.
        :type: str
        """
        allowed_values = ["DETECT", "BLOCK"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    @property
    def failure_threshold(self):
        """
        Gets the failure_threshold of this HumanInteractionChallenge.
        The number of failed requests before taking action. If unspecified, defaults to `10`.


        :return: The failure_threshold of this HumanInteractionChallenge.
        :rtype: int
        """
        return self._failure_threshold

    @failure_threshold.setter
    def failure_threshold(self, failure_threshold):
        """
        Sets the failure_threshold of this HumanInteractionChallenge.
        The number of failed requests before taking action. If unspecified, defaults to `10`.


        :param failure_threshold: The failure_threshold of this HumanInteractionChallenge.
        :type: int
        """
        self._failure_threshold = failure_threshold

    @property
    def action_expiration_in_seconds(self):
        """
        Gets the action_expiration_in_seconds of this HumanInteractionChallenge.
        The number of seconds between challenges for the same IP address. If unspecified, defaults to `60`.


        :return: The action_expiration_in_seconds of this HumanInteractionChallenge.
        :rtype: int
        """
        return self._action_expiration_in_seconds

    @action_expiration_in_seconds.setter
    def action_expiration_in_seconds(self, action_expiration_in_seconds):
        """
        Sets the action_expiration_in_seconds of this HumanInteractionChallenge.
        The number of seconds between challenges for the same IP address. If unspecified, defaults to `60`.


        :param action_expiration_in_seconds: The action_expiration_in_seconds of this HumanInteractionChallenge.
        :type: int
        """
        self._action_expiration_in_seconds = action_expiration_in_seconds

    @property
    def failure_threshold_expiration_in_seconds(self):
        """
        Gets the failure_threshold_expiration_in_seconds of this HumanInteractionChallenge.
        The number of seconds before the failure threshold resets. If unspecified, defaults to  `60`.


        :return: The failure_threshold_expiration_in_seconds of this HumanInteractionChallenge.
        :rtype: int
        """
        return self._failure_threshold_expiration_in_seconds

    @failure_threshold_expiration_in_seconds.setter
    def failure_threshold_expiration_in_seconds(self, failure_threshold_expiration_in_seconds):
        """
        Sets the failure_threshold_expiration_in_seconds of this HumanInteractionChallenge.
        The number of seconds before the failure threshold resets. If unspecified, defaults to  `60`.


        :param failure_threshold_expiration_in_seconds: The failure_threshold_expiration_in_seconds of this HumanInteractionChallenge.
        :type: int
        """
        self._failure_threshold_expiration_in_seconds = failure_threshold_expiration_in_seconds

    @property
    def interaction_threshold(self):
        """
        Gets the interaction_threshold of this HumanInteractionChallenge.
        The number of interactions required to pass the challenge. If unspecified, defaults to `3`.


        :return: The interaction_threshold of this HumanInteractionChallenge.
        :rtype: int
        """
        return self._interaction_threshold

    @interaction_threshold.setter
    def interaction_threshold(self, interaction_threshold):
        """
        Sets the interaction_threshold of this HumanInteractionChallenge.
        The number of interactions required to pass the challenge. If unspecified, defaults to `3`.


        :param interaction_threshold: The interaction_threshold of this HumanInteractionChallenge.
        :type: int
        """
        self._interaction_threshold = interaction_threshold

    @property
    def recording_period_in_seconds(self):
        """
        Gets the recording_period_in_seconds of this HumanInteractionChallenge.
        The number of seconds to record the interactions from the user. If unspecified, defaults to `15`.


        :return: The recording_period_in_seconds of this HumanInteractionChallenge.
        :rtype: int
        """
        return self._recording_period_in_seconds

    @recording_period_in_seconds.setter
    def recording_period_in_seconds(self, recording_period_in_seconds):
        """
        Sets the recording_period_in_seconds of this HumanInteractionChallenge.
        The number of seconds to record the interactions from the user. If unspecified, defaults to `15`.


        :param recording_period_in_seconds: The recording_period_in_seconds of this HumanInteractionChallenge.
        :type: int
        """
        self._recording_period_in_seconds = recording_period_in_seconds

    @property
    def set_http_header(self):
        """
        Gets the set_http_header of this HumanInteractionChallenge.
        Adds an additional HTTP header to requests that fail the challenge before being passed to the origin. Only applicable when the `action` is set to `DETECT`.


        :return: The set_http_header of this HumanInteractionChallenge.
        :rtype: Header
        """
        return self._set_http_header

    @set_http_header.setter
    def set_http_header(self, set_http_header):
        """
        Sets the set_http_header of this HumanInteractionChallenge.
        Adds an additional HTTP header to requests that fail the challenge before being passed to the origin. Only applicable when the `action` is set to `DETECT`.


        :param set_http_header: The set_http_header of this HumanInteractionChallenge.
        :type: Header
        """
        self._set_http_header = set_http_header

    @property
    def challenge_settings(self):
        """
        Gets the challenge_settings of this HumanInteractionChallenge.

        :return: The challenge_settings of this HumanInteractionChallenge.
        :rtype: BlockChallengeSettings
        """
        return self._challenge_settings

    @challenge_settings.setter
    def challenge_settings(self, challenge_settings):
        """
        Sets the challenge_settings of this HumanInteractionChallenge.

        :param challenge_settings: The challenge_settings of this HumanInteractionChallenge.
        :type: BlockChallengeSettings
        """
        self._challenge_settings = challenge_settings

    @property
    def is_nat_enabled(self):
        """
        Gets the is_nat_enabled of this HumanInteractionChallenge.
        When enabled, the user is identified not only by the IP address but also by an unique additional hash, which prevents blocking visitors with shared IP addresses.


        :return: The is_nat_enabled of this HumanInteractionChallenge.
        :rtype: bool
        """
        return self._is_nat_enabled

    @is_nat_enabled.setter
    def is_nat_enabled(self, is_nat_enabled):
        """
        Sets the is_nat_enabled of this HumanInteractionChallenge.
        When enabled, the user is identified not only by the IP address but also by an unique additional hash, which prevents blocking visitors with shared IP addresses.


        :param is_nat_enabled: The is_nat_enabled of this HumanInteractionChallenge.
        :type: bool
        """
        self._is_nat_enabled = is_nat_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .volume_attachment import VolumeAttachment
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParavirtualizedVolumeAttachment(VolumeAttachment):
    """
    A paravirtualized volume attachment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParavirtualizedVolumeAttachment object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.ParavirtualizedVolumeAttachment.attachment_type` attribute
        of this class is ``paravirtualized`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param attachment_type:
            The value to assign to the attachment_type property of this ParavirtualizedVolumeAttachment.
        :type attachment_type: str

        :param availability_domain:
            The value to assign to the availability_domain property of this ParavirtualizedVolumeAttachment.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ParavirtualizedVolumeAttachment.
        :type compartment_id: str

        :param device:
            The value to assign to the device property of this ParavirtualizedVolumeAttachment.
        :type device: str

        :param display_name:
            The value to assign to the display_name property of this ParavirtualizedVolumeAttachment.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ParavirtualizedVolumeAttachment.
        :type id: str

        :param instance_id:
            The value to assign to the instance_id property of this ParavirtualizedVolumeAttachment.
        :type instance_id: str

        :param is_read_only:
            The value to assign to the is_read_only property of this ParavirtualizedVolumeAttachment.
        :type is_read_only: bool

        :param is_shareable:
            The value to assign to the is_shareable property of this ParavirtualizedVolumeAttachment.
        :type is_shareable: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ParavirtualizedVolumeAttachment.
            Allowed values for this property are: "ATTACHING", "ATTACHED", "DETACHING", "DETACHED"
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this ParavirtualizedVolumeAttachment.
        :type time_created: datetime

        :param volume_id:
            The value to assign to the volume_id property of this ParavirtualizedVolumeAttachment.
        :type volume_id: str

        :param is_pv_encryption_in_transit_enabled:
            The value to assign to the is_pv_encryption_in_transit_enabled property of this ParavirtualizedVolumeAttachment.
        :type is_pv_encryption_in_transit_enabled: bool

        """
        self.swagger_types = {
            'attachment_type': 'str',
            'availability_domain': 'str',
            'compartment_id': 'str',
            'device': 'str',
            'display_name': 'str',
            'id': 'str',
            'instance_id': 'str',
            'is_read_only': 'bool',
            'is_shareable': 'bool',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'volume_id': 'str',
            'is_pv_encryption_in_transit_enabled': 'bool'
        }

        self.attribute_map = {
            'attachment_type': 'attachmentType',
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'device': 'device',
            'display_name': 'displayName',
            'id': 'id',
            'instance_id': 'instanceId',
            'is_read_only': 'isReadOnly',
            'is_shareable': 'isShareable',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'volume_id': 'volumeId',
            'is_pv_encryption_in_transit_enabled': 'isPvEncryptionInTransitEnabled'
        }

        self._attachment_type = None
        self._availability_domain = None
        self._compartment_id = None
        self._device = None
        self._display_name = None
        self._id = None
        self._instance_id = None
        self._is_read_only = None
        self._is_shareable = None
        self._lifecycle_state = None
        self._time_created = None
        self._volume_id = None
        self._is_pv_encryption_in_transit_enabled = None
        self._attachment_type = 'paravirtualized'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .condition import Condition
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CompositeCondition(Condition):
    """
    Composite Condition object with nested Condition
    """

    #: A constant which can be used with the composite_operator property of a CompositeCondition.
    #: This constant has a value of "AND"
    COMPOSITE_OPERATOR_AND = "AND"

    #: A constant which can be used with the composite_operator property of a CompositeCondition.
    #: This constant has a value of "OR"
    COMPOSITE_OPERATOR_OR = "OR"

    def __init__(self, **kwargs):
        """
        Initializes a new CompositeCondition object with values from keyword arguments. The default value of the :py:attr:`~oci.cloud_guard.models.CompositeCondition.kind` attribute
        of this class is ``COMPOSITE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this CompositeCondition.
            Allowed values for this property are: "COMPOSITE", "SIMPLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type kind: str

        :param left_operand:
            The value to assign to the left_operand property of this CompositeCondition.
        :type left_operand: Condition

        :param composite_operator:
            The value to assign to the composite_operator property of this CompositeCondition.
            Allowed values for this property are: "AND", "OR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type composite_operator: str

        :param right_operand:
            The value to assign to the right_operand property of this CompositeCondition.
        :type right_operand: Condition

        """
        self.swagger_types = {
            'kind': 'str',
            'left_operand': 'Condition',
            'composite_operator': 'str',
            'right_operand': 'Condition'
        }

        self.attribute_map = {
            'kind': 'kind',
            'left_operand': 'leftOperand',
            'composite_operator': 'compositeOperator',
            'right_operand': 'rightOperand'
        }

        self._kind = None
        self._left_operand = None
        self._composite_operator = None
        self._right_operand = None
        self._kind = 'COMPOSITE'

    @property
    def left_operand(self):
        """
        Gets the left_operand of this CompositeCondition.

        :return: The left_operand of this CompositeCondition.
        :rtype: Condition
        """
        return self._left_operand

    @left_operand.setter
    def left_operand(self, left_operand):
        """
        Sets the left_operand of this CompositeCondition.

        :param left_operand: The left_operand of this CompositeCondition.
        :type: Condition
        """
        self._left_operand = left_operand

    @property
    def composite_operator(self):
        """
        Gets the composite_operator of this CompositeCondition.
        Allowed values for this property are: "AND", "OR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The composite_operator of this CompositeCondition.
        :rtype: str
        """
        return self._composite_operator

    @composite_operator.setter
    def composite_operator(self, composite_operator):
        """
        Sets the composite_operator of this CompositeCondition.

        :param composite_operator: The composite_operator of this CompositeCondition.
        :type: str
        """
        allowed_values = ["AND", "OR"]
        if not value_allowed_none_or_none_sentinel(composite_operator, allowed_values):
            composite_operator = 'UNKNOWN_ENUM_VALUE'
        self._composite_operator = composite_operator

    @property
    def right_operand(self):
        """
        Gets the right_operand of this CompositeCondition.

        :return: The right_operand of this CompositeCondition.
        :rtype: Condition
        """
        return self._right_operand

    @right_operand.setter
    def right_operand(self, right_operand):
        """
        Sets the right_operand of this CompositeCondition.

        :param right_operand: The right_operand of this CompositeCondition.
        :type: Condition
        """
        self._right_operand = right_operand

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .push_down_operation import PushDownOperation
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FilterPush(PushDownOperation):
    """
    The information about a filter operator. The filter operator lets you select certain attributes from the inbound port to continue downstream to the outbound port.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FilterPush object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.FilterPush.model_type` attribute
        of this class is ``FILTER`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this FilterPush.
            Allowed values for this property are: "FILTER", "JOIN", "SELECT", "SORT", "QUERY"
        :type model_type: str

        :param filter_condition:
            The value to assign to the filter_condition property of this FilterPush.
        :type filter_condition: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'filter_condition': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'filter_condition': 'filterCondition'
        }

        self._model_type = None
        self._filter_condition = None
        self._model_type = 'FILTER'

    @property
    def filter_condition(self):
        """
        Gets the filter_condition of this FilterPush.
        The filter condition.


        :return: The filter_condition of this FilterPush.
        :rtype: str
        """
        return self._filter_condition

    @filter_condition.setter
    def filter_condition(self, filter_condition):
        """
        Sets the filter_condition of this FilterPush.
        The filter condition.


        :param filter_condition: The filter_condition of this FilterPush.
        :type: str
        """
        self._filter_condition = filter_condition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RegexMatchResult(object):
    """
    RegexMatchResult
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RegexMatchResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param matched_log_entry_end_index:
            The value to assign to the matched_log_entry_end_index property of this RegexMatchResult.
        :type matched_log_entry_end_index: int

        :param regex_score:
            The value to assign to the regex_score property of this RegexMatchResult.
        :type regex_score: int

        :param regex_steps_info:
            The value to assign to the regex_steps_info property of this RegexMatchResult.
        :type regex_steps_info: list[StepInfo]

        :param step_count:
            The value to assign to the step_count property of this RegexMatchResult.
        :type step_count: int

        :param sub_regexes_match_info:
            The value to assign to the sub_regexes_match_info property of this RegexMatchResult.
        :type sub_regexes_match_info: dict(str, MatchInfo)

        """
        self.swagger_types = {
            'matched_log_entry_end_index': 'int',
            'regex_score': 'int',
            'regex_steps_info': 'list[StepInfo]',
            'step_count': 'int',
            'sub_regexes_match_info': 'dict(str, MatchInfo)'
        }

        self.attribute_map = {
            'matched_log_entry_end_index': 'matchedLogEntryEndIndex',
            'regex_score': 'regexScore',
            'regex_steps_info': 'regexStepsInfo',
            'step_count': 'stepCount',
            'sub_regexes_match_info': 'subRegexesMatchInfo'
        }

        self._matched_log_entry_end_index = None
        self._regex_score = None
        self._regex_steps_info = None
        self._step_count = None
        self._sub_regexes_match_info = None

    @property
    def matched_log_entry_end_index(self):
        """
        Gets the matched_log_entry_end_index of this RegexMatchResult.
        matchedLogEntryEndIndex


        :return: The matched_log_entry_end_index of this RegexMatchResult.
        :rtype: int
        """
        return self._matched_log_entry_end_index

    @matched_log_entry_end_index.setter
    def matched_log_entry_end_index(self, matched_log_entry_end_index):
        """
        Sets the matched_log_entry_end_index of this RegexMatchResult.
        matchedLogEntryEndIndex


        :param matched_log_entry_end_index: The matched_log_entry_end_index of this RegexMatchResult.
        :type: int
        """
        self._matched_log_entry_end_index = matched_log_entry_end_index

    @property
    def regex_score(self):
        """
        Gets the regex_score of this RegexMatchResult.
        regexScore


        :return: The regex_score of this RegexMatchResult.
        :rtype: int
        """
        return self._regex_score

    @regex_score.setter
    def regex_score(self, regex_score):
        """
        Sets the regex_score of this RegexMatchResult.
        regexScore


        :param regex_score: The regex_score of this RegexMatchResult.
        :type: int
        """
        self._regex_score = regex_score

    @property
    def regex_steps_info(self):
        """
        Gets the regex_steps_info of this RegexMatchResult.
        regexStepsInfo


        :return: The regex_steps_info of this RegexMatchResult.
        :rtype: list[StepInfo]
        """
        return self._regex_steps_info

    @regex_steps_info.setter
    def regex_steps_info(self, regex_steps_info):
        """
        Sets the regex_steps_info of this RegexMatchResult.
        regexStepsInfo


        :param regex_steps_info: The regex_steps_info of this RegexMatchResult.
        :type: list[StepInfo]
        """
        self._regex_steps_info = regex_steps_info

    @property
    def step_count(self):
        """
        Gets the step_count of this RegexMatchResult.
        stepCount


        :return: The step_count of this RegexMatchResult.
        :rtype: int
        """
        return self._step_count

    @step_count.setter
    def step_count(self, step_count):
        """
        Sets the step_count of this RegexMatchResult.
        stepCount


        :param step_count: The step_count of this RegexMatchResult.
        :type: int
        """
        self._step_count = step_count

    @property
    def sub_regexes_match_info(self):
        """
        Gets the sub_regexes_match_info of this RegexMatchResult.
        subRegexesMatchInfo


        :return: The sub_regexes_match_info of this RegexMatchResult.
        :rtype: dict(str, MatchInfo)
        """
        return self._sub_regexes_match_info

    @sub_regexes_match_info.setter
    def sub_regexes_match_info(self, sub_regexes_match_info):
        """
        Sets the sub_regexes_match_info of this RegexMatchResult.
        subRegexesMatchInfo


        :param sub_regexes_match_info: The sub_regexes_match_info of this RegexMatchResult.
        :type: dict(str, MatchInfo)
        """
        self._sub_regexes_match_info = sub_regexes_match_info

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScheduleSecretDeletionDetails(object):
    """
    Details for scheduling the deletion of the specified secret.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScheduleSecretDeletionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_of_deletion:
            The value to assign to the time_of_deletion property of this ScheduleSecretDeletionDetails.
        :type time_of_deletion: datetime

        """
        self.swagger_types = {
            'time_of_deletion': 'datetime'
        }

        self.attribute_map = {
            'time_of_deletion': 'timeOfDeletion'
        }

        self._time_of_deletion = None

    @property
    def time_of_deletion(self):
        """
        Gets the time_of_deletion of this ScheduleSecretDeletionDetails.
        An optional property indicating when to delete the secret version, expressed in `RFC 3339`__ timestamp format.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_deletion of this ScheduleSecretDeletionDetails.
        :rtype: datetime
        """
        return self._time_of_deletion

    @time_of_deletion.setter
    def time_of_deletion(self, time_of_deletion):
        """
        Sets the time_of_deletion of this ScheduleSecretDeletionDetails.
        An optional property indicating when to delete the secret version, expressed in `RFC 3339`__ timestamp format.

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_deletion: The time_of_deletion of this ScheduleSecretDeletionDetails.
        :type: datetime
        """
        self._time_of_deletion = time_of_deletion

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SourceApplicationSummary(object):
    """
    An application running in the source environment that is available for export.
    """

    #: A constant which can be used with the type property of a SourceApplicationSummary.
    #: This constant has a value of "JCS"
    TYPE_JCS = "JCS"

    #: A constant which can be used with the type property of a SourceApplicationSummary.
    #: This constant has a value of "SOACS"
    TYPE_SOACS = "SOACS"

    #: A constant which can be used with the type property of a SourceApplicationSummary.
    #: This constant has a value of "OIC"
    TYPE_OIC = "OIC"

    #: A constant which can be used with the type property of a SourceApplicationSummary.
    #: This constant has a value of "OAC"
    TYPE_OAC = "OAC"

    #: A constant which can be used with the type property of a SourceApplicationSummary.
    #: This constant has a value of "ICS"
    TYPE_ICS = "ICS"

    #: A constant which can be used with the type property of a SourceApplicationSummary.
    #: This constant has a value of "PCS"
    TYPE_PCS = "PCS"

    def __init__(self, **kwargs):
        """
        Initializes a new SourceApplicationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SourceApplicationSummary.
        :type name: str

        :param type:
            The value to assign to the type property of this SourceApplicationSummary.
            Allowed values for this property are: "JCS", "SOACS", "OIC", "OAC", "ICS", "PCS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param source_id:
            The value to assign to the source_id property of this SourceApplicationSummary.
        :type source_id: str

        :param version:
            The value to assign to the version property of this SourceApplicationSummary.
        :type version: str

        :param state:
            The value to assign to the state property of this SourceApplicationSummary.
        :type state: str

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'source_id': 'str',
            'version': 'str',
            'state': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'source_id': 'sourceId',
            'version': 'version',
            'state': 'state'
        }

        self._name = None
        self._type = None
        self._source_id = None
        self._version = None
        self._state = None

    @property
    def name(self):
        """
        Gets the name of this SourceApplicationSummary.
        The name of the application


        :return: The name of this SourceApplicationSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SourceApplicationSummary.
        The name of the application


        :param name: The name of this SourceApplicationSummary.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this SourceApplicationSummary.
        The type of application

        Allowed values for this property are: "JCS", "SOACS", "OIC", "OAC", "ICS", "PCS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this SourceApplicationSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SourceApplicationSummary.
        The type of application


        :param type: The type of this SourceApplicationSummary.
        :type: str
        """
        allowed_values = ["JCS", "SOACS", "OIC", "OAC", "ICS", "PCS"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def source_id(self):
        """
        Gets the source_id of this SourceApplicationSummary.
        Unique identifier (OCID) for the Source to which the application belongs


        :return: The source_id of this SourceApplicationSummary.
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this SourceApplicationSummary.
        Unique identifier (OCID) for the Source to which the application belongs


        :param source_id: The source_id of this SourceApplicationSummary.
        :type: str
        """
        self._source_id = source_id

    @property
    def version(self):
        """
        Gets the version of this SourceApplicationSummary.
        The version of the application server


        :return: The version of this SourceApplicationSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SourceApplicationSummary.
        The version of the application server


        :param version: The version of this SourceApplicationSummary.
        :type: str
        """
        self._version = version

    @property
    def state(self):
        """
        Gets the state of this SourceApplicationSummary.
        The current application running state


        :return: The state of this SourceApplicationSummary.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this SourceApplicationSummary.
        The current application running state


        :param state: The state of this SourceApplicationSummary.
        :type: str
        """
        self._state = state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
